@@ -26,6 +26,9 @@ import math
 
 from lxml import etree
 from PIL import Image
+from shapely.geometry import Polygon
+from shapely import affinity
+
 
 # Add printing for every thread
 from threading import Lock
@@ -58,6 +61,7 @@ def compute_lines(segmentation: np.ndarray,
         if o is None:
             continue
         if sl.dim1(o) < 2 * scale * filter_strength or sl.dim0(o) < scale * filter_strength:
+            s_print(f"Filter strength of {filter_strength} too high. Skipping detected line object…")
             continue
         mask = (segmentation[o] == i + 1)
         if np.amax(mask) == 0:
@@ -320,6 +324,7 @@ def pagelineseg(xmlfile: str,
     s_print(f"[{name}] Extract Textlines from TextRegions")
 
     im = Image.open(imgpath)
+    width, height = im.size
 
     if remove_images:
         imageutils.remove_images(im, root)
@@ -327,12 +332,12 @@ def pagelineseg(xmlfile: str,
     pageutils.remove_existing_textlines(root)
 
     for coord_idx, coord in enumerate(sorted(coordmap)):
-        coords = coordmap[coord]['coords']
+        region_coords = coordmap[coord]['coords']
 
-        if len(coords) < 3:
+        if len(region_coords) < 3:
             continue
 
-        cropped, [min_x, min_y, max_x, max_y] = imgmanipulate.cutout(im, coords)
+        cropped, [min_x, min_y, max_x, max_y] = imgmanipulate.cutout(im, region_coords)
 
         if coordmap[coord].get("orientation"):
             orientation = coordmap[coord]['orientation']
@@ -371,7 +376,7 @@ def pagelineseg(xmlfile: str,
 
         # Interpret whole region as TextLine if no TextLines are found
         if not lines or len(lines) == 0:
-            coord_str = " ".join([f"{x},{y}" for x, y in coords])
+            coord_str = " ".join([f"{x},{y}" for x, y in region_coords])
             textregion = root.find(f'.//{{*}}TextRegion[@id="{coord}"]')
             if orientation:
                 textregion.set('orientation', str(orientation))
@@ -383,8 +388,9 @@ def pagelineseg(xmlfile: str,
                 if coordmap[coord]["type"] == "drop-capital":
                     coord_str = coordmap[coord]["coordstring"]
                 else:
-                    coords = ((x + min_x, y + min_y) for x, y in poly)
-                    coord_str = " ".join([f"{int(x)},{int(y)}" for x, y in coords])
+                    line_coords = Polygon([(x + min_x, y + min_y) for x, y in poly])
+                    sanitized_coords = pageutils.sanitize(line_coords, Polygon(region_coords), width, height)
+                    coord_str = " ".join([f"{int(x)},{int(y)}" for x, y in sanitized_coords])
 
                 textregion = root.find(f'.//{{*}}TextRegion[@id="{coord}"]')
                 if orientation:
